(*  GREATIS PROGRESS WHEEL                                    *)
(*  Copyright (C) 2014 Greatis Software                       *)
(*                                                            *)
(*  http://www.greatis.com/delphicb/progresswheel/            *)

unit Main;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, ComCtrls, ProgressWheel, ExtCtrls, StdCtrls, XPMan, ShellAPI;

type
  TMainForm = class(TForm)
    Timer: TTimer;
    XPManifest: TXPManifest;
    GroupBoxInnerSize: TGroupBox;
    ProgressWheelInnerSize0: TProgressWheel;
    ProgressWheelInnerSize50: TProgressWheel;
    ProgressWheelInnerSize90: TProgressWheel;
    LabelInnerSize0: TLabel;
    LabelInnerSize50: TLabel;
    LabelInnerSize90: TLabel;
    GroupBoxInnerColor: TGroupBox;
    LabelInnerColorWhite: TLabel;
    LabelInnerColorGray: TLabel;
    LabelInnerColorBlack: TLabel;
    ProgressWheelInnerColorWhite: TProgressWheel;
    ProgressWheelInnerColorGray: TProgressWheel;
    ProgressWheelInnerColorBlack: TProgressWheel;
    GroupBoxText: TGroupBox;
    LabelTextStandard: TLabel;
    LabelTextCustom: TLabel;
    LabelTextCustomMultiline: TLabel;
    ProgressWheelTextStandard: TProgressWheel;
    ProgressWheelTextCustom: TProgressWheel;
    ProgressWheelTextCustomMultiline: TProgressWheel;
    GroupBoxColors: TGroupBox;
    LabelColors1: TLabel;
    LabelColors2: TLabel;
    LabelColors3: TLabel;
    ProgressWheelColors1: TProgressWheel;
    ProgressWheelColors2: TProgressWheel;
    ProgressWheelColors3: TProgressWheel;
    GroupBoxProperties: TGroupBox;
    LabelPreview: TLabel;
    ProgressWheelProperties: TProgressWheel;
    TrackBarPosition: TTrackBar;
    LabelPosition: TLabel;
    LabelStartAngle: TLabel;
    TrackBarStartAngle: TTrackBar;
    LabelInnerSize: TLabel;
    TrackBarInnerSize: TTrackBar;
    LabelColorInner: TLabel;
    ButtonColorInner: TButton;
    LabelColorDoneMin: TLabel;
    ButtonColorDoneMin: TButton;
    LabelColorDoneMax: TLabel;
    ButtonColorDoneMax: TButton;
    LabelColorRemain: TLabel;
    ButtonColorRemain: TButton;
    LabelGradientMode: TLabel;
    ComboBoxGradientMode: TComboBox;
    ButtonMore: TButton;
    ButtonClose: TButton;
    ColorDialog: TColorDialog;
    ShapeColorInner: TShape;
    ShapeColorRemain: TShape;
    ShapeColorDoneMin: TShape;
    ShapeColorDoneMax: TShape;
    procedure TimerTimer(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure ProgressWheelTextCustomText(Sender: TObject; var Text: String);
    procedure ProgressWheelTextCustomMultilineText(Sender: TObject; var Text: String);
    procedure TrackBarPositionChange(Sender: TObject);
    procedure TrackBarStartAngleChange(Sender: TObject);
    procedure TrackBarInnerSizeChange(Sender: TObject);
    procedure ButtonColorInnerClick(Sender: TObject);
    procedure ButtonColorRemainClick(Sender: TObject);
    procedure ButtonColorDoneMinClick(Sender: TObject);
    procedure ButtonColorDoneMaxClick(Sender: TObject);
    procedure ComboBoxGradientModeChange(Sender: TObject);
    procedure ButtonMoreClick(Sender: TObject);
    procedure ButtonCloseClick(Sender: TObject);
  private
    { Private declarations }
    //ColorIndex: Integer;
    Direction: Integer;
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;

implementation

{$R *.dfm}

const
  Colors: array[0..3] of TColor = (clRed,$00A000,$0080FF,$FF8040);

procedure TMainForm.TimerTimer(Sender: TObject);
var
  i: Integer;
  C: TColor;
begin
  for i:=0 to Pred(ComponentCount) do
  begin
    if Components[i] is TProgressWheel then
      with TProgressWheel(Components[i]) do
        if Tag<>-2 then
        begin
          Position:=Position+5;
          if Position=Max then
          begin
            if Tag<>-1 then
            begin
              Tag:=Tag+1;
              if Tag>High(Colors) then Tag:=0;
              ColorRemain:=ColorDoneMax;
              ColorDoneMax:=Colors[Tag];
            end
            else
            begin
              C:=ColorRemain;
              ColorRemain:=ColorDoneMax;
              ColorDoneMax:=C;
            end;
            Position:=Min;
          end;
        end;
  end;
end;

procedure TMainForm.FormCreate(Sender: TObject);
var
  LF: TLogFont;
begin
  SystemParametersInfo(SPI_GETICONTITLELOGFONT,SizeOf(LF),@LF,0);
  with LF,Font do
  begin
    ScaleBy(Abs(lfHeight),Abs(Height));
    Handle:=CreateFontIndirect(LF);
  end;
  Direction:=1;
end;

procedure TMainForm.ProgressWheelTextCustomText(Sender: TObject; var Text: String);
begin
  with Sender as TProgressWheel do
    Text:=IntToStr(Position)+'/'+IntToStr(Max);
end;

procedure TMainForm.ProgressWheelTextCustomMultilineText(Sender: TObject; var Text: String);
begin
  with Sender as TProgressWheel do
    Text:=IntToStr(Position)+' out'#13#10' of '+IntToStr(Max);
end;

procedure TMainForm.TrackBarPositionChange(Sender: TObject);
begin
  ProgressWheelProperties.Position:=TrackBarPosition.Position;
end;

procedure TMainForm.TrackBarStartAngleChange(Sender: TObject);
begin
  ProgressWheelProperties.StartAngle:=TrackBarStartAngle.Position;
end;

procedure TMainForm.TrackBarInnerSizeChange(Sender: TObject);
begin
  ProgressWheelProperties.InnerSize:=TrackBarInnerSize.Position;
end;

procedure TMainForm.ButtonColorInnerClick(Sender: TObject);
begin
  with ColorDialog do
  begin
    Color:=ProgressWheelProperties.ColorInner;
    if Execute then
    begin
      ProgressWheelProperties.ColorInner:=Color;
      ShapeColorInner.Brush.Color:=Color;
    end;
  end;
end;

procedure TMainForm.ButtonColorRemainClick(Sender: TObject);
begin
  with ColorDialog do
  begin
    Color:=ProgressWheelProperties.ColorRemain;
    if Execute then
    begin
      ProgressWheelProperties.ColorRemain:=Color;
      ShapeColorRemain.Brush.Color:=Color;
    end;
  end;
end;

procedure TMainForm.ButtonColorDoneMinClick(Sender: TObject);
begin
  with ColorDialog do
  begin
    Color:=ProgressWheelProperties.ColorDoneMin;
    if Execute then
    begin
      ProgressWheelProperties.ColorDoneMin:=Color;
      ShapeColorDoneMin.Brush.Color:=Color;
    end;
  end;
end;

procedure TMainForm.ButtonColorDoneMaxClick(Sender: TObject);
begin
  with ColorDialog do
  begin
    Color:=ProgressWheelProperties.ColorDoneMax;
    if Execute then
    begin
      ProgressWheelProperties.ColorDoneMax:=Color;
      ShapeColorDoneMax.Brush.Color:=Color;
    end;
  end;
end;

procedure TMainForm.ComboBoxGradientModeChange(Sender: TObject);
begin
  ProgressWheelProperties.GradientMode:=TGradientMode((Sender as TComboBox).ItemIndex);
end;

procedure TMainForm.ButtonMoreClick(Sender: TObject);
begin
  ShellExecute(Handle,'open','http://www.greatis.com/delphicb/progresswheel/',nil,nil,SW_SHOWDEFAULT);
end;

procedure TMainForm.ButtonCloseClick(Sender: TObject);
begin
  Application.Terminate;
end;

end.
